.. :changelog:

History
-------

Pending Release
---------------

.. Insert new release notes below this line

1.0.1 (2019-02-07)
------------------

* Update PyPI development status as inactive. This package is no longer
  maintained, see README.rst.

1.0.0 (2017-06-18)
------------------

* First release on PyPI, featuring ``kwargs_only`` decorator.
